{% load i18n static %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    {% include "djangocopy/metadata.html" %}

    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" integrity="sha384-wvfXpqpZZVQGK6TAh5PVlGOfQNHSoD2xbE+QkPxCAFlNEevoEH3Sl0sibVcOQVnN" crossorigin="anonymous">
    <link rel="stylesheet" href="{% static "css/djangocopy.css" %}">

    {% block djangocopy-head %}{% endblock %}
</head>

<body id="{% block pageid %}{% endblock %}" class="{% block body-class %}{% endblock %}" {% if onload %}onload={{ onload }}{% endif %}>
    {% navbar %}
    <div class="{% block djangocopy-container %}container{% endblock %}">
        {% block djangocopy-content %}{% endblock %}
    </div>
    <!--{% include "djangocopy/footer.html" %}-->

    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js" integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" crossorigin="anonymous"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous"></script>
    <script src="{% static "js/wearprotection.js" %}"></script>
    <script src="{% static "js/djangocopy.js" %}"></script>

    {% block djangocopy-script %}{% endblock %}
</body>

</html>