{% extends "djangocopy/base.html" %}
{% load i18n bootstrap %}

{% block title %}Password Reset{% endblock %}

{% block djangocopy-content %}
    <div class="container">
      <div class="col-md-6 col-md-offset-3">
	    <h1>Password Reset</h1>
	    <p>Enter your e-mail address below, and we'll send you an e-mail allowing you to reset it.</p>

	    <form method="POST" action="" >
	        {% csrf_token %}
	        {{ form|bootstrap }}
	        <div class="form-actions">
	          <input class="btn btn-primary" type="submit" value="Reset my Password" />
	        </div>
	    </form>

	    <br>
	    <p>Please contact us at <a href="mailto:admin@altimapa.com?subject=Password reset problems">admin@altimapa.com</a> if you have any trouble resetting your password.</p>
	  </div>
	</div>

	<script>
	    $("#id_email").focus();
	</script>
{% endblock %}

