{% extends "djangocopy/base.html" %}
{% load i18n bootstrap %}

{% block title %}Password Reset Confirm{% endblock %}

{% block djangocopy-content %}
    {% if validlink %}
	    <div class="container">
	      <div class="col-md-6 col-md-offset-3">
	        <h1>Password Reset</h1>
            <p>Please enter and confirm your new password.</p>

	        <form method="POST" action="" >
	            {% csrf_token %}
	            {{ form|bootstrap }}
	            <div class="form-actions">
	              <input class="btn btn-primary" type="submit" value="Change My Password" />
	            </div>
	        </form>

	        <br>
	        <p>Please contact us if you have any trouble resetting your password.</p>
	      </div>
	    </div>

    {% else %}

        <h1>Password reset failed</h1>
        <p>The password reset link was invalid, possibly because it has already been used. Please request a new password reset.</p>

    {% endif %}
{% endblock %}
