{% load static %}

{% if metadata.title %}
<title>{{ metadata.title }}</title>
<meta property="og:title" content="{{ metadata.title }}" />
<meta name="twitter:title" content="{{ metadata.title }}" />
{% endif %}

{% if metadata.description %}
<meta name="description" content="{{ metadata.description }}" />
<meta property="og:description" content="{{ metadata.description }}" />
<meta name="twitter:description" content="{{ metadata.description }}" />
{% endif %}

{% if metadata.image %}
<meta property="og:image" content="{{ metadata.image }}" />
<meta name="twitter:image" content="{{ metadata.image }}" />
{% endif %}

{% if metadata.keywords %}
<meta name="keywords" content="{{ metadata.keywords }}" />
{% endif %}

{% if request.site %}
<meta property="og:url" content="{{ request.site }}" />
{% endif %}

<meta property="og:type" content={{"website"}} />
