{% load i18n static djangocopy-navbar %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    {% include "djangocopy/metadata.html" %}

    {% if debug %}
        <link rel="stylesheet" href="{% static "css/bootstrap.min.css" %}">
        <link rel="stylesheet" href="{% static "css/font-awesome.min.css" %}">
        <!--- Load jQuery ahead of page -->
        <script src="{% static "js/jquery-3.3.1.min.js" %}"></script>
     {% else %}
        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" integrity="sha384-wvfXpqpZZVQGK6TAh5PVlGOfQNHSoD2xbE+QkPxCAFlNEevoEH3Sl0sibVcOQVnN" crossorigin="anonymous">
        <!--- Load jQuery ahead of page -->
        <script src="https://code.jquery.com/jquery-3.4.1.min.js" integrity="sha256-CSXorXvZcTkaix6Yvo6HppcZGetbYMGWSFlBw8HfCJo=" crossorigin="anonymous"></script>
    {% endif %}
    <link rel="stylesheet" href="{% static "css/djangocopy.css" %}">

    <link rel="icon" href="/static/favicon.ico" />
    <link rel="apple-touch-icon-precomposed" sizes="57x57" href="/static/apple-touch-icon-57x57.png" />
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="/static/apple-touch-icon-114x114.png" />
    <link rel="apple-touch-icon-precomposed" sizes="72x72" href="/static/apple-touch-icon-72x72.png" />
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="/static/apple-touch-icon-144x144.png" />
    <link rel="apple-touch-icon-precomposed" sizes="60x60" href="/static/apple-touch-icon-60x60.png" />
    <link rel="apple-touch-icon-precomposed" sizes="120x120" href="/static/apple-touch-icon-120x120.png" />
    <link rel="apple-touch-icon-precomposed" sizes="76x76" href="/static/apple-touch-icon-76x76.png" />
    <link rel="apple-touch-icon-precomposed" sizes="152x152" href="/static/apple-touch-icon-152x152.png" />
    <link rel="icon" type="image/png" href="/static/favicon-196x196.png" sizes="196x196" />
    <link rel="icon" type="image/png" href="/static/favicon-96x96.png" sizes="96x96" />
    <link rel="icon" type="image/png" href="/static/favicon-32x32.png" sizes="32x32" />
    <link rel="icon" type="image/png" href="/static/favicon-16x16.png" sizes="16x16" />
    <link rel="icon" type="image/png" href="/static/favicon-128.png" sizes="128x128" />
    <meta name="application-name" content="&nbsp;"/>
    <meta name="msapplication-TileColor" content="#FFFFFF" />
    <meta name="msapplication-TileImage" content="/static/mstile-144x144.png" />
    <meta name="msapplication-square70x70logo" content="/static/mstile-70x70.png" />
    <meta name="msapplication-square150x150logo" content="/static/mstile-150x150.png" />
    <meta name="msapplication-wide310x150logo" content="/static/mstile-310x150.png" />
    <meta name="msapplication-square310x310logo" content="/static/mstile-310x310.png" />

    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
        <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->

    {% block djangocopy-head %}{% endblock %}
</head>

<body id="{% block pageid %}{% endblock %}" class="{% block body-class %}{% endblock %}" {% if onload %}onload={{ onload }}{% endif %}>
    {% navbar %}
    <div class="{% block djangocopy-container %}container{% endblock %}">
        {% include "djangocopy/messages.html" %}
        {% block djangocopy-content %}{% endblock %}
    </div>
    <!--{% include "djangocopy/footer.html" %}-->

    {% if debug %}
        <script src="{% static "js/popper.min.js" %}"></script>
        <script src="{% static "js/bootstrap.min.js" %}"></script>
    {% else %}
        <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js" integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" crossorigin="anonymous"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous"></script>
    {% endif %}
    <script src="{% static "js/wearprotection.js" %}"></script>
    <script src="{% static "js/djangocopy.js" %}"></script>

    {% block djangocopy-script %}{% endblock %}
</body>

</html>