{% extends "djangocopy/base.html" %}
{% load i18n %}

{% block breadcrumbs %}
<ul class="breadcrumbs">
  <li>{% trans "Error 400" %}</li>
</ul>
{% endblock breadcrumbs %}

{% block title %}{% trans "Bad request" %}{% endblock title %}

{% block body-class %}error-400{% endblock body-class %}

{% block djangocopy-content %}
    <div class="container">
        <div class="col-sm-7">
            <h1>{% trans "Bad request" %}</h1>
            <p>{% trans "Sorry, but the request was malformed." %}</p>
        </div>
    </div>
    {{ block.super }}
{% endblock djangocopy-content %}


